<?php

namespace SGalinski\SgJobs\Domain\Repository;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use SGalinski\SgJobs\Domain\Model\Company;
use TYPO3\CMS\Extbase\Persistence\QueryInterface;
use TYPO3\CMS\Extbase\Persistence\Repository;

/**
 * Company Repository
 */
class CompanyRepository extends Repository {
	/**
	 * initializes the object
	 */
	public function initializeObject(): void {
		$querySettings = $this->createQuery()->getQuerySettings();
		$querySettings->setRespectStoragePage(FALSE);
		$querySettings->setIgnoreEnableFields(TRUE);
		$querySettings->setEnableFieldsToBeIgnored(['disabled']);
		$this->setDefaultQuerySettings($querySettings);
	}

	/**
	 * Returns all countries filtered by page id
	 *
	 * @param int $pageUid
	 * @return mixed
	 * @throws \InvalidArgumentException
	 */
	public function getAllCountries($pageUid) {
		/** @var QueryInterface $query */
		$query = $this->createQuery();
		$querySettings = $query->getQuerySettings();
		$querySettings->setStoragePageIds([$pageUid]);
		$querySettings->setLanguageUid($GLOBALS['TSFE']->sys_language_uid);

		$query->setQuerySettings($querySettings);

		$query->setOrderings(
			[
				'sorting' => QueryInterface::ORDER_ASCENDING,
			]
		);

		$result = $query->execute()->toArray();

		$countryArray = [''];
		/** @var Company $company */
		foreach ($result as $company) {
			$countryName = $company->getCountry();
			$countryArray[$countryName] = $countryName;
		}

		return $countryArray;
	}

	/**
	 * Returns all filtered cities
	 *
	 * @param int $pageUid
	 * @return mixed
	 * @throws \InvalidArgumentException
	 */
	public function getAllCities($pageUid) {
		/** @var QueryInterface $query */
		$query = $this->createQuery();
		$querySettings = $query->getQuerySettings();
		$querySettings->setStoragePageIds([$pageUid]);
		$querySettings->setLanguageUid($GLOBALS['TSFE']->sys_language_uid);

		$query->setQuerySettings($querySettings);

		$query->setOrderings(
			[
				'sorting' => QueryInterface::ORDER_ASCENDING,
			]
		);

		$result = $query->execute()->toArray();

		$cityArray = [''];
		/** @var Company $company */
		foreach ($result as $company) {
			$cityName = $company->getCity();
			$cityArray[$cityName] = $cityName;
		}

		return $cityArray;
	}

	/**
	 * Returns all companies filtered by page id
	 *
	 * @param int $pageUid
	 * @return mixed
	 * @throws \InvalidArgumentException
	 */
	public function getAllCompanyNames($pageUid) {
		/** @var QueryInterface $query */
		$query = $this->createQuery();
		$querySettings = $query->getQuerySettings();
		$querySettings->setStoragePageIds([$pageUid]);
		$querySettings->setLanguageUid($GLOBALS['TSFE']->sys_language_uid);

		$query->setQuerySettings($querySettings);

		$query->setOrderings(
			[
				'sorting' => QueryInterface::ORDER_ASCENDING,
			]
		);

		$result = $query->execute()->toArray();

		$companyArray = [''];
		/** @var Company $company */
		foreach ($result as $company) {
			$companyName = $company->getName();
			$companyArray[$companyName] = $companyName;
		}

		return $companyArray;
	}

	/**
	 * Returns all companies filtered by page id
	 *
	 * @param int $pageUid
	 * @return mixed
	 * @throws \InvalidArgumentException
	 */
	public function getAllCompanies($pageUid) {
		/** @var QueryInterface $query */
		$query = $this->createQuery();
		$querySettings = $query->getQuerySettings();
		$querySettings->setStoragePageIds([$pageUid]);
		$querySettings->setLanguageUid($GLOBALS['TSFE']->sys_language_uid);

		$query->setQuerySettings($querySettings);

		$query->setOrderings(
			[
				'sorting' => QueryInterface::ORDER_ASCENDING,
			]
		);

		$companyConstraints[] = $query->equals('pid', $pageUid);
		$query->matching($query->logicalAnd($companyConstraints));

		return $query->execute();
	}
}
